pub enum Protocol {
PossiblyPlain,
TLS,
}Expand description
The protocol of the NATS server
Variants
PossiblyPlain
Plaintext with the option to later upgrade to TLS
This option should only be used when esplicity wanting to connect using a plaintext connection. Using this option over the public internet or other untrusted networks leaves the client open to MITM attacks.
Corresponds to the nats scheme.
TLS
TLS connection
Requires the TCP connection to successfully upgrade to TLS.
Corresponds to the tls scheme.