HeaderMap

Struct HeaderMap 

pub struct HeaderMap { /* private fields */ }
A set of NATS headers

HeaderMap is a multimap of HeaderName.

Implementations

Source

impl HeaderMap

pub const fn new() -> Self

Create an empty HeaderMap

The map will be created without any capacity. This function will not allocate.

Consider using the FromIterator, Extend implementations if the final length is known upfront.

pub fn get(&self, name: &HeaderName) -> Option<&HeaderValue>

pub fn get_all<'a>( &'a self, name: &HeaderName, ) -> impl DoubleEndedIterator<Item = &'a HeaderValue> + use<'a>

pub fn insert(&mut self, name: HeaderName, value: HeaderValue)

pub fn append(&mut self, name: HeaderName, value: HeaderValue)

pub fn remove(&mut self, name: &HeaderName)

pub fn keys_len(&self) -> usize

Returns the number of keys stored in the map

This number will be less than or equal to HeaderMap::len.

pub fn len(&self) -> usize

Returns the number of headers stored in the map

This number represents the total number of values stored in the map. This number can be greater than or equal to the number of keys stored.

pub fn is_empty(&self) -> bool

Returns true if the map contains no elements

pub fn clear(&mut self)

Clear the map, removing all key-value pairs. Keeps the allocated memory for reuse