pub struct HeaderMap { /* private fields */ }Expand description
A set of NATS headers
HeaderMap is a multimap of HeaderName.
Implementations
Sourceimpl HeaderMap
impl HeaderMap
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Create an empty HeaderMap
The map will be created without any capacity. This function will not allocate.
Consider using the FromIterator, Extend implementations if the final
length is known upfront.
pub fn get(&self, name: &HeaderName) -> Option<&HeaderValue>
pub fn get_all<'a>( &'a self, name: &HeaderName, ) -> impl DoubleEndedIterator<Item = &'a HeaderValue> + use<'a>
pub fn insert(&mut self, name: HeaderName, value: HeaderValue)
pub fn append(&mut self, name: HeaderName, value: HeaderValue)
pub fn remove(&mut self, name: &HeaderName)
Sourcepub fn keys_len(&self) -> usize
pub fn keys_len(&self) -> usize
Returns the number of keys stored in the map
This number will be less than or equal to HeaderMap::len.